@@ -6,7 +6,7 @@ import os
 import re
 import tornado.options
 from tornado.web import (Application, RequestHandler, StaticFileHandler as _StaticFileHandler,
-                         RedirectHandler, HTTPError)
+                         RedirectHandler, HTTPError, URLSpec)
 import tornado.wsgi
 from tornado.wsgi import WSGIApplication as _WSGIApplication
 from torweb.urls import url
@@ -38,20 +38,39 @@ def get_modules(prefix, parent):
 
 class WebApplication(Application):
     def __call__(self, request): 
+        #print """Called by HTTPServer to execute the request."""
+        #print "##################################################"
+        if not hasattr(self, "add_slash"):
+            setattr(self, "add_slash", False)
+        _add_slash = getattr(self, "add_slash")
         transforms = [t(request) for t in self.transforms]
         handler = None
         args = []
         kwargs = {}
-        if request.path.endswith("/"):
-            if request.method in ("GET", "HEAD"):
-                uri = request.path.rstrip("/")
-                if uri:  # don't try to redirect '/' to ''
+        if _add_slash == False:
+            # removeslash
+            if request.path.endswith("/"):
+                if request.method in ("GET", "HEAD"):
+                    uri = request.path.rstrip("/")
+                    if uri:  # don't try to redirect '/' to ''
+                        if request.query:
+                            uri += "?" + request.query
+                        hdr = RedirectHandler(self, request, url=uri)
+                        hdr._execute(transforms, *args, **kwargs)
+                        return hdr
+                else:
+                    raise HTTPError(404)
+        else:
+            # addslash
+            li = [_compile for _compile in self._static_urls if re.compile(_compile).match(request.path)]
+            if len(li) == 0 and not request.path.endswith("/"):
+                if request.method in ("GET", "HEAD"):
+                    uri = request.path + "/"
                     if request.query:
                         uri += "?" + request.query
                     hdr = RedirectHandler(self, request, url=uri)
                     hdr._execute(transforms, *args, **kwargs)
                     return hdr
-            else:
                 raise HTTPError(404)
         super(WebApplication, self).__call__(request)
         #print """Called by HTTPServer to execute the request."""
@@ -216,19 +235,11 @@ def make_application(app, debug=False, wsgi=False):
         kw["debug"] = debug
         return kw
     url_handlers = url.handlers
-    url_handlers = [(u, c, _set_debug(kw)) for u, c, kw in url_handlers]
-    _static_urls = [url for url, cls, kw in url.handlers if kw.has_key("path") and hasattr(cls, 'static_handler') and cls.static_handler==True]
-    #for u, cls, kw in url_handlers:
-    #    if kw.has_key('path') and hasattr(cls, 'static_handler') and cls.static_handler == True: 
-    #        static_handler = cls
-    #        _static_urls.append(u)
-    #if not static_handler:
-    #    url_handlers.append((r"/static/(.*)", StaticFileHandler, {"path": os.path.join(app_path, 'static')}))
-    #    _static_urls.append(r'/static/(.*)')
-    #url_handlers.reverse()
+    url_handlers = [URLSpec(spec._path, spec.handler_class, _set_debug(spec.kwargs), spec.name) for spec in url_handlers]
+    _static_urls = [spec._path for spec in url.handlers if spec.kwargs.has_key("path") and hasattr(spec.handler_class, 'static_handler') and spec.handler_class.static_handler==True]
+    #url_handlers = [(u, c, _set_debug(kw)) for u, c, kw in url_handlers]
+    #_static_urls = [url for url, cls, kw in url.handlers if kw.has_key("path") and hasattr(cls, 'static_handler') and cls.static_handler==True]
     url_handlers.extend(except_url.handlers)
-    #for u, cls, kw in url_handlers:
-    #    print "%s \r\t\t\t\t--> %s(%s)" % (u, cls, kw)
     if debug:
         application = DebugApplication(url_handlers, **{'debug':debug})
     else:
