@@ -27,8 +27,8 @@ class Command(object):
 def urls(app):
     def action():
         """show all urls"""
-        for url, handler, kw in app.url_handlers:
-            print "%s\t\t\t%s(%s)"%(url, handler, kw)
+        for spec in app.url_handlers:
+            print "%s\t\t\t%s(%s)"%(spec._path, spec.handler_class, spec.kwargs)
 
     return action
 
