@@ -68,7 +68,8 @@ class Yaml_Config(object):
         sessionstore_name = self.settings.get('session_store', 'MemorySessionStore')
         module = __import__('torweb.sessions', {}, {}, sessionstore_name) 
         cls =  getattr(module, sessionstore_name)
-        print 'session store: %s' % cls.__name__
+        #import logging
+        #logging.info('session store: %s' % cls.__name__)
         if cls.__name__ == 'MemcachedSessionStore':
             #print 'session store: %s' % cls.__name__
             return cls(self.settings.get('memcached', ['127.0.0.1:11211']))
