@@ -71,34 +71,23 @@ class BaseHandler(RequestHandler):
         after request
         '''
         pass
-        #print 'finish'
-    #@cached_property
-    #def session(self):
-    #    '''根据session_sid值来获取session对象，或者初始化一个session对象'''
-    #    session_store = self.application.session_store
-    #    sid = self.cookies.get('session_id')
-    #    print "sid--> %s" % sid
-    #    if sid is None:
-    #        return session_store.new()
-    #    else:
-    #        return session_store.get(sid.value)
     @cached_property
     def session(self):
         '''根据session_sid值来获取session对象，或者初始化一个session对象'''
         session_store = self.application.session_store
         sid = self.cookies.get('session_id')
-        print "sid--> %s" % sid
+        #print "sid--> %s" % sid
         if session_store.__class__.__name__ == 'RedisSessionStore':
             if sid is None:
                 _sessionsid = self.application.session_store.generate_sid()
-                print "cookie generate_sid--%s" % _sessionsid
+                #print "cookie generate_sid--%s" % _sessionsid
             else:
                 _sessionsid = sid.value
-                print "cookie sessionsid--%s" % _sessionsid
+                #print "cookie sessionsid--%s" % _sessionsid
             from torweb.sessions import RedisSession
             return RedisSession(self.application.session_store, _sessionsid)
         else:
-            print "session_store -- %s" % session_store
+            #print "session_store -- %s" % session_store
             if sid is None:
                 return session_store.new()
             else:
