@@ -265,7 +265,7 @@ class RedisSessionStore:
         self.redis.hset(self.prefixed(sid), name, pickle.dumps(session_data))
         if expiry:
             self.redis.expire(self.prefixed(sid), expiry)
-        print "save session: set_session--%s-%s-%s" % (sid, session_data, name)
+        #print "save session: set_session--%s-%s-%s" % (sid, session_data, name)
     def save(self, session):
         session._save()
  
