@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 # created: zhangpeng <zhangpeng@ivtime.com>
 
+from tornado.web import URLSpec
 from code import interact
 
 class Url(object):
@@ -10,7 +11,9 @@ class Url(object):
 
     def __call__(self, url, **kwds):
         def _(cls):
-            self.handlers.append((url, cls, kwds))
+            kwname = kwds.get("name", None)
+            name = kwname or "%s.%s" % (cls.__module__, cls.__name__)
+            self.handlers.append(URLSpec(url, cls, kwds, name=name))
             return cls
         return _
 url = Url()
